==> prada_1.26.0.zip: prada/doc/prada2cellHTS.R <==
###################################################
### chunk number 1: prepare
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkkTzcZ/R.INSTALL2cff5902/prada/inst/doc/prada2cellHTS.Rnw"
library("cellHTS")


###################################################
### chunk number 2: readPlateData
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkkTzcZ/R.INSTALL2cff5902/prada/inst/doc/prada2cellHTS.Rnw"
experimentName = "ApoptosisScreen"
dataPath = system.file("extdata", package = "prada")
x = readPlateData("Platelist.txt", name = experimentName, 
                  path = dataPath, verbose = FALSE)
x


###################################################
### chunk number 3: configure
###################################################
#line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkkTzcZ/R.INSTALL2cff5902/prada/inst/doc/prada2cellHTS.Rnw"
confFile = file.path(dataPath, "Plateconf.txt")
logFile = file.path(dataPath, "Screenlog.txt")
descripFile = file.path(dataPath, "Description.txt")
x = configure(x, confFile, logFile, descripFile)


###################################################
### chunk number 4: normalize
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkkTzcZ/R.INSTALL2cff5902/prada/inst/doc/prada2cellHTS.Rnw"
x$xnorm <- -log10(x$xraw)
x$state["normalized"] <- TRUE


###################################################
### chunk number 5: report eval=FALSE
###################################################
## #line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpkkTzcZ/R.INSTALL2cff5902/prada/inst/doc/prada2cellHTS.Rnw"
## geneIDFile = file.path(dataPath, "GeneIDs.txt")
## x = annotate(x, geneIDFile)
## writeReport(x, force = TRUE, plotPlateArgs = list(xrange = c(0.2,
##     1.5), xcol=c("white", "red")), 
##     imageScreenArgs = list(zrange = c(-2, 6.5), ar = 1))

==> prada_1.28.0.zip: prada/doc/prada2cellHTS.R <==
###################################################
### chunk number 1: prepare
###################################################
#line 50 "prada2cellHTS.Rnw"
library("cellHTS")


###################################################
### chunk number 2: readPlateData
###################################################
#line 56 "prada2cellHTS.Rnw"
experimentName = "ApoptosisScreen"
dataPath = system.file("extdata", package = "prada")
x = readPlateData("Platelist.txt", name = experimentName, 
                  path = dataPath, verbose = FALSE)
x


###################################################
### chunk number 3: configure
###################################################
#line 69 "prada2cellHTS.Rnw"
confFile = file.path(dataPath, "Plateconf.txt")
logFile = file.path(dataPath, "Screenlog.txt")
descripFile = file.path(dataPath, "Description.txt")
x = configure(x, confFile, logFile, descripFile)


###################################################
### chunk number 4: normalize
###################################################
#line 82 "prada2cellHTS.Rnw"
x$xnorm <- -log10(x$xraw)
x$state["normalized"] <- TRUE


###################################################
### chunk number 5: report eval=FALSE
###################################################
## #line 90 "prada2cellHTS.Rnw"
## geneIDFile = file.path(dataPath, "GeneIDs.txt")
## x = annotate(x, geneIDFile)
## writeReport(x, force = TRUE, plotPlateArgs = list(xrange = c(0.2,
##     1.5), xcol=c("white", "red")), 
##     imageScreenArgs = list(zrange = c(-2, 6.5), ar = 1))
